<?php # This file has been generated at:  Mon Nov 12 14:25:49 MSK 2012

__("Title");
__("Title or Content");
__("Link");
__("Content");
__("Article Date");

__("Delete article");
__("Mark as read");
__("Set starred");
__("Publish article");
__("Assign tags");
__("Assign label");
__("Modify score");

__("General");
__("Interface");
__("Advanced");

__('This option is useful when you are reading several planet-type aggregators with partially colliding userbase. When disabled, it forces same posts from different feeds to appear only once.');
__('Display expanded list of feed articles, instead of separate displays for headlines and article content');
__('Automatically open next feed with unread articles after marking one as read');
__('This option enables sending daily digest of new (and unread) headlines on your configured e-mail address');
__('This option enables marking articles as read automatically while you scroll article list.');
__('Strip all but most common HTML tags when reading articles.');
__('When auto-detecting tags in articles these tags will not be applied (comma-separated list).');
__('When this option is enabled, headlines in Special feeds and Labels are grouped by feeds');
__('Customize CSS stylesheet to your liking');
__('Use feed-specified date to sort headlines instead of local import date.');
__('Click to register your SSL client certificate with tt-rss');
__('Uses UTC timezone');
__('Purge articles after this number of days (0 - disables)');
__('Default interval between feed updates');
__('Amount of articles to display at once');
__('Allow duplicate posts');
__('Enable feed categories');
__('Show content preview in headlines list');
__('Short date format');
__('Long date format');
__('Combined feed display');
__('Hide feeds with no unread messages');
__('On catchup show next feed');
__('Sort feeds by unread articles count');
__('Reverse headline order (oldest first)');
__('Enable e-mail digest');
__('Confirm marking feed as read');
__('Automatically mark articles as read');
__('Strip unsafe tags from articles');
__('Blacklisted tags');
__('Maximum age of fresh articles (in hours)');
__('Mark articles in e-mail digest as read');
__('Automatically expand articles in combined mode');
__('Purge unread articles');
__('Show special feeds when hiding read feeds');
__('Group headlines in virtual feeds');
__('Do not show images in articles');
__('Enable external API');
__('User timezone');
__('Customize stylesheet');
__('Sort headlines by feed date');
__('Login with an SSL certificate');
__('Try to send digests around specified time');
__('Assign articles to labels automatically');
?>
